@@ -9,8 +9,8 @@ template = os.path.join(template_dir, 'template.html')
 
 ### Optional parameters
 options = { 'baseurl':"", # if not set, relative URLs will be generated
-            'sitename':"Zed A. Shaw",
-            'slogan': "A website full of things Zed makes and says.",
+            'sitename':"Lamson Project(TM)",
+            'slogan': "Lamson The Python SMTP Server and Framework",
             'extensions':['.txt'],
             'format': 'text/x-textile',
             'siteurl': 'http://lamsonproject.org',
