@@ -1,12 +1,11 @@
 from app.model import post, confirmation
 from email.utils import parseaddr
 from config.settings import relay, database
-from lamson import view 
+from lamson import view, queue
 from lamson.routing import route, Router, stateless
 import logging
 
 
-Router.defaults(post_name="[a-zA-Z0-9.]+")
 
 @route("(post_name)@osb\\.(host)")
 def START(message, post_name=None, address=None, host=None):
@@ -46,6 +45,8 @@ def POSTING(message, post_name=None, host=None, action=None):
         post.post(post_name, address, message)
         msg = view.respond('page_ready.msg', locals())
         relay.deliver(msg)
+        index_q = queue.Queue("run/posts")
+        index_q.push(message)
     elif action == "delete":
         post.delete(post_name, address)
     else:
