@@ -18,8 +18,14 @@ database_config = {
 
 handlers = ['app.handlers.osb']
 
-router_defaults = {'host': 'test\\.com'}
+router_defaults = {'host': 'test\\.com', 'post_name': "[a-zA-Z0-9.]+"}
 
 template_config = {'dir': 'app', 'module': 'templates'}
 
 BLOG_BASE="app/data/posts"
+
+# this is for when you run the config.queue boot
+queue_config = {'queue': 'run/posts', 'sleep': 10}
+
+queue_handlers = ['app.handlers.index']
+
