@@ -63,6 +63,24 @@ class MailRequest(object):
         resent_ccs = self.msg.get_all('resent-cc', [])
         return getaddresses(frs + tos + ccs + resent_tos + resent_ccs)
 
+    def all_parts(self):
+        """
+        Used to bust out the attachments (or parts) of an email.  It
+        *always* returns an list with something in it.  If the message
+        has attachments then it include each one once (and doesn't duplicate)
+        the main message).  If the message has NO attachments, then it 
+        simply returns an list with self.msg in it for processing.
+
+        The returned values are Python email base messages, no MailRequests.
+        """
+        parts = [m for m in self.msg.walk() if m != self.msg]
+        
+        if not parts:
+            parts = [self.msg]
+
+        return parts
+
+
     def matches(self, expr):
         """Attempts to match the regex on any possible recipient in
         the email's list."""
@@ -72,13 +90,15 @@ class MailRequest(object):
         else:
             return None
 
-    def body(self):
+    def body(self, index=0):
         """
-        Returns the body of the mail.  If the body is too
-        complex then this probably won't work, so use the self.msg
-        attribute directly.
+        Returns the decoded body of the message, and if it's multipart then
+        it will return the one at index (default is 0).
         """
-        return self.msg.get_payload()
+        if self.msg.is_multipart():
+            return self.all_parts()[index].get_payload(decode=True)
+        else:
+            return self.msg.get_payload(decode=True)
 
     def __contains__(self, key):
         return key in self.msg
