@@ -414,7 +414,7 @@ class route(object):
         This is NOT SUPPORTED.  It is here just so that if you try to apply
         this decorator to a class's method it will barf on you.
         """
-        raise RuntimeError("Not supported on methods yet, only module functions.")
+        raise NotImplementedError("Not supported on methods yet, only module functions.")
 
     def parse_format(self, format, captures):
         """Does the grunt work of convertion format+captures into the regex."""
