@@ -17,7 +17,7 @@ import logging
 import imp
 
 
-def import_settings(boot_also, from_dir=None):
+def import_settings(boot_also, from_dir=None, boot_module="config.boot"):
     """Used to import the settings in a Lamson project."""
     if from_dir:
         sys.path.append(from_dir)
@@ -25,12 +25,12 @@ def import_settings(boot_also, from_dir=None):
     from config import settings
 
     if boot_also:
-        from config import boot
+        __import__(boot_module, globals(), locals())
 
     return settings
 
 
-def daemonize(options, files_preserve):
+def daemonize(pid, cd, chroot, uid, gid, umask, files_preserve=[], do_open=True):
     """
     Uses python-daemonize to do all the junk needed to make a
     server a server.  It supports all the features daemonize
@@ -38,22 +38,25 @@ def daemonize(options, files_preserve):
     some serious configuration on the system.
     """
     context = daemon.DaemonContext()
-    context.pidfile=pidlockfile.PIDLockFile(options["pid"])
+    context.pidfile=pidlockfile.PIDLockFile(pid)
     context.stdout=open("logs/lamson.out","a+")
     context.stderr=open("logs/lamson.err","a+")
     context.files_preserve = files_preserve
-    context.working_directory=os.path.expanduser(options["cd"])
+    context.working_directory=os.path.expanduser(cd)
     
-    if options['chroot']: 
-        context.chroot_directory = os.path.expanduser(options['chroot'])
-    if options['uid']: 
-        context.uid = options['uid']
-    if options['gid']: 
-        context.gid = options['gid']
-    if options['umask']:
-        context.umask = options['umask']
+    if chroot: 
+        context.chroot_directory = os.path.expanduser(chroot)
+    if uid != False: 
+        context.uid = uid
+    if gid != False: 
+        context.gid = gid
+    if umask != False:
+        context.umask = umask
 
-    context.open()
+    if do_open:
+        context.open()
+
+    return context
 
 
 def configure_database(settings, also_create=False):
@@ -74,14 +77,14 @@ def configure_database(settings, also_create=False):
 
 
 
-def make_fake_settings(options):
+def make_fake_settings(host, port):
     """
     When running as a logging server we need a fake settings module to work with
     since the logging server can be run in any directory, so there may not be
     a config/settings.py file to import.
     """
     settings = imp.new_module('settings')
-    settings.receiver = server.SMTPReceiver(options["host"], options["port"])
+    settings.receiver = server.SMTPReceiver(host, port)
     settings.relay = None
     settings.database = None
     settings.log_file = "logs/lamson.log"
