@@ -40,7 +40,6 @@ def test_determine_kwargs():
 
 def test_tokenize():
     tokens = args.tokenize(['test', '--num', '1', '--help', '--stuff', 'The remainder.'])
-    print tokens
     assert args.match(tokens, 'word')
     assert args.match(tokens, 'option')
     assert args.match(tokens, 'int')
@@ -48,6 +47,14 @@ def test_tokenize():
     assert args.match(tokens, 'option')
     assert args.match(tokens, 'string')
 
+    # test a condition where there is a remainder that's not identified
+    tokens = args.tokenize(['stop', '--pid', 'run/log.pid'])
+    assert tokens
+    assert args.match(tokens, 'word')
+    assert args.match(tokens, 'option')
+    assert args.match(tokens, 'string')
+
+
 def test_parse():
     command, options = args.parse(['test', '--num', '1', '--help', '--stuff', 'The remainder.', '--tail'])
     assert command, "There should be a command."
