@@ -1,15 +1,9 @@
 from nose.tools import *
-from lamson import utils
+from lamson import utils, view
 
 
 def test_make_fake_settings():
-    options = {
-        'host': 'localhost',
-        'port': 8800,
-        'debug': 1
-    }
-
-    settings = utils.make_fake_settings(options)
+    settings = utils.make_fake_settings('localhost', 8800)
     assert settings
     assert settings.receiver
     assert settings.relay == None
@@ -18,15 +12,33 @@ def test_make_fake_settings():
     settings.receiver.close()
 
 def test_import_settings():
+    loader = view.LOADER
+
+    settings = utils.import_settings(True, from_dir='examples/osb', boot_module='config.testing')
+    assert settings
+    assert settings.receiver_config
+    assert settings.database_config
+    assert settings.log_file
+
+    view.LOADER = loader
     settings = utils.import_settings(False, from_dir='examples/osb')
     assert settings
     assert settings.receiver_config
     assert settings.database_config
     assert settings.log_file
 
+
 def test_configure_database():
     settings = utils.import_settings(False, from_dir='examples/osb')
     assert settings
+
     db = utils.configure_database(settings.database_config, also_create=False)
 
+    # without settings
+    db = utils.configure_database(None, also_create=False)
 
+
+def test_daemonize_not_fully():
+    context = utils.daemonize("run/tests.pid", ".", None, None, None, None, do_open=False)
+    context = utils.daemonize("run/tests.pid", ".", "/tmp", 0, 0, 0002, do_open=False)
+    assert context
